@@ -410,7 +410,7 @@ Moe, moe, kyun!")
    `(helm-source-header ((,class (:foreground ,white-0 :background ,blue-3 :bold nil))))
    `(helm-visible-mark ((,class (:foreground ,magenta-2 :background ,magenta-00))))
 
-   ;; Dired/Dired+
+   ;; Dired/Dired+/Diredfl
    `(dired-directory ((,class (:foreground ,blue-1 :bold t))))
    `(dired-flagged ((,class (:foreground ,red-1))))
    `(dired-header ((,class (:foreground ,black-5  :background ,green-01 :bold t))))
@@ -429,6 +429,7 @@ Moe, moe, kyun!")
    `(diredp-dir-name ((,class (:foreground ,blue-1 :background ,LIGHT_BG :bold t))))
    `(diredp-dir-priv ((,class (:foreground ,blue-1 :background ,LIGHT_BG))))
    `(diredp-display-msg ((,class (:foreground ,orange-2))))
+   `(diredp-exec-priv ((,class (:foreground ,red-3 :background ,orange-0))))
    `(diredp-executable-tag ((,class (:foreground ,green-2))))
    `(diredp-file-name ((,class (:foreground ,black-5))))
    `(diredp-file-suffix ((,class (:foreground ,orange-3))))
@@ -442,10 +443,35 @@ Moe, moe, kyun!")
    `(diredp-number ((,class (:foreground ,green-3))))
    `(diredp-other-priv ((,class (:foreground ,white-0 :background ,blue-3))))
    `(diredp-rare-priv ((,class (:foreground ,white-0 :background ,purple-2))))
-   `(diredp-symlink ((,class (:foreground ,magenta-3))))
    `(diredp-read-priv ((,class (:foreground ,green-4 :background ,green-0))))
+   `(diredp-symlink ((,class (:foreground ,magenta-3))))
    `(diredp-write-priv ((,class (:foreground ,blue-5 :background ,blue-0))))
-   `(diredp-exec-priv ((,class (:foreground ,red-3 :background ,orange-0))))
+   `(diredfl-autofile-name ((,class (:foreground ,cyan-2))))
+   `(diredfl-compressed-file-name ((,class (:foreground ,white-4))))
+   `(diredfl-compressed-file-suffix ((,class (:foreground ,purple-2))))
+   `(diredfl-date-time ((,class (:foreground ,blue-3 :background ,blue-00))))
+   `(diredfl-deletion ((,class (:foreground ,white-0, :background ,red-3))))
+   `(diredfl-deletion-file-name ((,class (:foreground ,red-2))))
+   `(diredfl-dir-heading ((,class (:foreground ,black-5 :background ,green-01 :bold t))))
+   `(diredfl-dir-name ((,class (:foreground ,blue-1 :background ,LIGHT_BG :bold t))))
+   `(diredfl-dir-priv ((,class (:foreground ,blue-1 :background ,LIGHT_BG))))
+   `(diredfl-exec-priv ((,class (:foreground ,red-3 :background ,orange-0))))
+   `(diredfl-executable-tag ((,class (:foreground ,green-2))))
+   `(diredfl-file-name ((,class (:foreground ,black-5))))
+   `(diredfl-file-suffix ((,class (:foreground ,orange-3))))
+   `(diredfl-flag-mark ((,class (:foreground ,white-0 :background ,magenta-3 :bold t))))
+   `(diredfl-flag-mark-line ((,class (:foreground ,black-5 :background ,magenta-1))))
+   `(diredfl-ignored-file-name ((,class (:foreground ,white-4))))
+   `(diredfl-link-priv ((,class (:foreground ,magenta-3))))
+   `(diredfl-no-priv ((,class (:foreground ,yellow-3 :background ,yellow-00))))
+   `(diredfl-number ((,class (:foreground ,green-3))))
+   `(diredfl-other-priv ((,class (:foreground ,white-0 :background ,blue-3))))
+   `(diredfl-rare-priv ((,class (:foreground ,white-0 :background ,purple-2))))
+   `(diredfl-read-priv ((,class (:foreground ,green-4 :background ,green-0))))
+   `(diredfl-symlink ((,class (:foreground ,magenta-3))))
+   `(diredfl-tagged-autofile-name ((,class (:foreground ,cyan-3))))
+   `(diredfl-write-priv ((,class (:foreground ,blue-5 :background ,blue-0))))
+
 
    ;; Transient (Mainly used in Magit)
    `(transient-argument ((,class (:foreground ,orange-3 :background ,orange-000 :weight bold))))
